==> estateplat-common-1.2.4-20210520.024327-767-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyiqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlDyiq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlDyiqBdc extends QlfQlDyiq {
    private String dfgydqlrzjzldm;
    private String dfgydqlrzjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfxydqlrzjzldm;
    private String dfxydqlrzjzlmc;

    @XmlAttribute(
            name = "DFGYDQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzldm() {
        return dfgydqlrzjzldm;
    }

    public void setDfgydqlrzjzldm(String dfgydqlrzjzldm) {
        this.dfgydqlrzjzldm = dfgydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFGYDQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzlmc() {
        return dfgydqlrzjzlmc;
    }

    public void setDfgydqlrzjzlmc(String dfgydqlrzjzlmc) {
        this.dfgydqlrzjzlmc = dfgydqlrzjzlmc;
    }

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFXYDQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxydqlrzjzldm() {
        return dfxydqlrzjzldm;
    }

    public void setDfxydqlrzjzldm(String dfxydqlrzjzldm) {
        this.dfxydqlrzjzldm = dfxydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFXYDQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxydqlrzjzlmc() {
        return dfxydqlrzjzlmc;
    }

    public void setDfxydqlrzjzlmc(String dfxydqlrzjzlmc) {
        this.dfxydqlrzjzlmc = dfxydqlrzjzlmc;
    }
}

==> estateplat-common-1.2.4-20230322.082938-1149-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyiqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.QlfQlDyiqNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@Table(name = "QLF_QL_DYIQ")
public class QlfQlDyiqBdc extends QlfQlDyiqNew {
    private String dfgydqlrzjzldm;
    private String dfgydqlrzjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfxydqlrzjzldm;
    private String dfxydqlrzjzlmc;

    @XmlAttribute(
            name = "DFGYDQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzldm() {
        return dfgydqlrzjzldm;
    }

    public void setDfgydqlrzjzldm(String dfgydqlrzjzldm) {
        this.dfgydqlrzjzldm = dfgydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFGYDQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzlmc() {
        return dfgydqlrzjzlmc;
    }

    public void setDfgydqlrzjzlmc(String dfgydqlrzjzlmc) {
        this.dfgydqlrzjzlmc = dfgydqlrzjzlmc;
    }

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFXYDQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxydqlrzjzldm() {
        return dfxydqlrzjzldm;
    }

    public void setDfxydqlrzjzldm(String dfxydqlrzjzldm) {
        this.dfxydqlrzjzldm = dfxydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFXYDQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxydqlrzjzlmc() {
        return dfxydqlrzjzlmc;
    }

    public void setDfxydqlrzjzlmc(String dfxydqlrzjzlmc) {
        this.dfxydqlrzjzlmc = dfxydqlrzjzlmc;
    }
}
